@@ -29,7 +29,7 @@ use XML::LibXML::XPathContext;
 use IO::Handle; # for FH reads called as methods
 
 BEGIN {
-$VERSION = "2.0121"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "2.0125"; # VERSION TEMPLATE: DO NOT CHANGE
 $ABI_VERSION = 2;
 require Exporter;
 require DynaLoader;
@@ -1775,7 +1775,7 @@ package XML::LibXML::Text;
 use vars qw(@ISA);
 @ISA = ('XML::LibXML::Node');
 
-sub attributes { return undef; }
+sub attributes { return; }
 
 sub deleteDataString {
     my ($node, $string, $all) = @_;
